RustLogFilter

Struct RustLogFilter 

pub struct RustLogFilter { /* private fields */ }
A filter consists of one or more comma-separated directives which match on Record.

Each directive may have a corresponding maximum verbosity Level which enables records that match.

Less exclusive levels (like trace or info) are considered to be more verbose than more exclusive levels (like error or warn).

Read more from the crate level documentation about the directive syntax and use cases.